parse_control_point

Function parse_control_point 

fn parse_control_point(
    iter: &mut Peekable<Cloned<Iter<'_, u8>>>,
) -> Result<ControlPoint<ShapePosition<CSSFloat>, CSSFloat>, ()>
Parse a pair of values that describe the curve control point.

Note: when the reference is None, the ’s reference defaults to the commands coordinate mode (absolute or relative).